summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/kvirc/kernel/kvi_app_setup.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/kvirc/kernel/kvi_app_setup.cpp b/src/kvirc/kernel/kvi_app_setup.cpp
index 27555f0b..de8b1a11 100644
--- a/src/kvirc/kernel/kvi_app_setup.cpp
+++ b/src/kvirc/kernel/kvi_app_setup.cpp
@@ -546,11 +546,11 @@ void KviApp::findGlobalKvircDirectory()
#else // !COMPILE_ON_WINDOWS
// Since I had many problems with it
- // because of strange distributions or KDEDIRS
+ // because of strange distributions or TDEDIRS
// I do it in that way...
#ifdef COMPILE_KDE_SUPPORT
// KDE compilation ...
// The things usually go installed into $KDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
// Look in the main KDE directory
KStandardDirs * d = dirs();
if(d)
@@ -558,8 +558,8 @@ void KviApp::findGlobalKvircDirectory()
m_szGlobalKvircDir = locate("appdata","");
if(checkGlobalKvircDirectory(m_szGlobalKvircDir))return;
#ifdef HAVE_GETENV
- //KDEDIR sanity check...
- m_szGlobalKvircDir = getenv("KDEDIR");
+ //TDEDIR sanity check...
+ m_szGlobalKvircDir = getenv("TDEDIR");
m_szGlobalKvircDir+="/share/apps/kvirc/" KVI_VERSION_BRANCH;
if(checkGlobalKvircDirectory(m_szGlobalKvircDir))return;
#endif
@@ -567,7 +567,7 @@ void KviApp::findGlobalKvircDirectory()
// FAILED ? Check the usual way...
#endif //COMPILE_WITH_KDE
// Non KDE compilation , or not found under $KDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
// Check for MacOS X Bundle compilation
#ifdef Q_OS_MACX
@@ -613,10 +613,10 @@ void KviApp::findGlobalKvircDirectory()
#ifdef COMPILE_KDE_SUPPORT
KviMessageBox::warning("Unable to find the shared Kvirc directory.\n"\
- "The usual path for this directory is $KDEDIR/share/apps/kvirc.\n"\
+ "The usual path for this directory is $TDEDIR/share/apps/kvirc.\n"\
"Are you sure that 'make install' worked correctly ?\n"\
"Please make sure that you have the read permission to that directory\n"\
- "and you have set KDEDIR correctly. You may also try to rerun 'make install'.\n"\
+ "and you have set TDEDIR correctly. You may also try to rerun 'make install'.\n"\
"A detailed explaination of the Kvirc directory system is in the INSTALL document\n"\
"shipped with the kvirc source dirstribution.\n"\
"Trying to run anyway...");
@@ -546,11 +546,11 @@ void KviApp::findGlobalKvircDirectory()
#ifdef COMPILE_KDE_SUPPORT
// KDE compilation ...
- // The things usually go installed into $KDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
+ // The things usually go installed into $TDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
// Look in the main KDE directory
KStandardDirs * d = dirs();
@@ -567,7 +567,7 @@ void KviApp::findGlobalKvircDirectory()
// FAILED ? Check the usual way...
#endif //COMPILE_WITH_KDE
- // Non KDE compilation , or not found under $KDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
+ // Non KDE compilation , or not found under $TDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
// Check for MacOS X Bundle compilation
#ifdef Q_OS_MACX